import type { MediaSize } from './types/MediaSize';
/**
 * Gets the duration of the video in seconds.
 * @param uri The full on device uri for the media item.
 * @returns Duration of the video in number of seconds.
 */
export declare function getVideoDuration(uri: string): Promise<number>;
/**
 * Gets the horizontal (x) and vertical (y) pixels of the media item, either image or video.
 * @param uri The full on device uri for the media item.
 * @param mediaType - Either 'image' or 'video. If passing an image, 0 will always be returned.
 * @returns MediaSize with height and width of the media item in pixels.
 */
export declare function getDimensions(uri: string, mediaType: 'video' | 'image'): Promise<MediaSize>;
/**
 * Gets the Mime type of the media file at the passed Uri.
 * @param uri The full on device uri for the media item.
 * @returns The Mime type of the media file.
 */
export declare function getMimeType(uri: string): Promise<string>;
/**
 * Gets the string date time of the media file at the passed Uri. The date time is retrieved
 * from the Exif data if an image is passed and creation date if a video is passed.
 * @param uri The full file uri or the asset-library path for the media item.
 * @param fileType Either image or video.
 * @returns The timestamp of the media file.
 */
export declare function getTimestamp(uri: string, mediaType: 'image' | 'video'): Promise<string>;
